Core (Fornax.Seo)1.6.0 Fornax.Seo

Core Module

Extends the Fornax DSL with SEO meta tag generators

Functions and values

Function or value Description

rsl page license

Full Usage: rsl page license

Parameters:
Returns: HtmlElement A <script> tag containing an RSL license for the given page

Generates an inline RSL license for an individual web page

page : ContentObject

The web page to which the license will apply

license : License option

An optional License; if None, the return value of License.FreeAndSearchable is used

Returns: HtmlElement

A <script> tag containing an RSL license for the given page

seo page

Full Usage: seo page

Parameters:
Returns: HtmlElement list A list of <meta> tags with OpenGraph data and a <script> tag with JSON-LD structured data

Generates structured data and OpenGraph tags

If page's Url is relative or malformed, it will be rejected with a warning message. See this post for advice on avoiding relative URLs in structured data

page : ContentObject
Returns: HtmlElement list

A list of <meta> tags with OpenGraph data and a <script> tag with JSON-LD structured data

ArgumentException Thrown if either page's ObjectType or ContentType is not recognized by the Schema.org specification, or if OpenGraphType is not a recognized OpenGraph object type

socialMedia author

Full Usage: socialMedia author

Parameters:
Returns: HtmlElement list A list of social media links decorated with matching Font Awesome icons

Generates links to the social media profiles of the given author

author : ContentCreator
Returns: HtmlElement list

A list of social media links decorated with matching Font Awesome icons

Type something to start searching.