Models Module
Public representations of web content metadata
Types
| Type | Description |
|
Represents the author of a web content item |
|
|
Represents a web content item; by default, represents the host website |
Public representations of web content metadata
| Type | Description |
|
Represents the author of a web content item |
|
|
Represents a web content item; by default, represents the host website |