Rsl (Fornax.Seo)1.6.0 Fornax.Seo

Rsl Module

A (partial) implementation of the RSL 1.0 specification

Types and nested modules

Type/Module Description

DOM

The component elements of an RSL document

Validation

XML validation utilities for RSL licenses

Attribute

An RSL element attribute

AttributeValue

Permitted values of an RSL element attribute

IRslElement

Provides RSL elements with HTML generation methods

PermittedUsage

A unique RSL element specifying the permitted or prohibited usage of a licensed work

UniqueElement

An RSL element that should not have the same type attribute as any sibling element

Functions and values

Function or value Description

toHtmlElement elem

Full Usage: toHtmlElement elem

Parameters:
    elem : 'T - An RSL element type provided by the DOM module

Returns: HtmlElement
Modifiers: inline
Type parameters: 'T
elem : 'T

An RSL element type provided by the DOM module

Returns: HtmlElement

toHtmlString elem

Full Usage: toHtmlString elem

Parameters:
    elem : 'T - An RSL element type provided by the DOM module

Returns: string
Modifiers: inline
Type parameters: 'T
elem : 'T

An RSL element type provided by the DOM module

Returns: string

toXmlDocument elem

Full Usage: toXmlDocument elem

Parameters:
    elem : 'T - An RSL element type provided by the DOM module

Returns: DocumentBuilder<'T>
Modifiers: inline
Type parameters: 'T

Transforms an RSL element into an XML document or fragment, without validating the contents

elem : 'T

An RSL element type provided by the DOM module

Returns: DocumentBuilder<'T>

Type something to start searching.