Accepts (Fornax.Seo)1.6.0 Fornax.Seo

Accepts Type

The <accepts> element of an RSL document

One of these may be a child of Payment

Record fields

Record Field Description

Method

Full Usage: Method

Field type: string

A stringified JSON object of protocol-specific metadata, such as pricing and settlement instructions

Field type: string

Type

Full Usage: Type

Field type: string

A media type identifying the payment protocol and payload format

Field type: string

Type something to start searching.