Alternate (Fornax.Seo)1.6.0 Fornax.Seo

Alternate Type

The <alternate> element of an RSL document

One of these may be a child of Content

Record fields

Record Field Description

Type

Full Usage: Type

Field type: string option

The media type of an alternate representation of the licensed work; e.g., text/plain, application/json

Field type: string option

Url

Full Usage: Url

Field type: Uri

The URL of this alternate representation

Field type: Uri

Type something to start searching.