Amount (Fornax.Seo)1.6.0 Fornax.Seo

Amount Type

The <amount> element of an RSL document

One of these may be a child of Payment

Record fields

Record Field Description

Currency

Full Usage: Currency

Field type: CurrencyCode

An ISO 4217 currency code

Field type: CurrencyCode

Value

Full Usage: Value

Field type: decimal

The monetary cost for permitted use of the licensed work

Field type: decimal

Type something to start searching.