Content (Fornax.Seo)1.6.0 Fornax.Seo

Content Type

The <content> element of an RSL document

One or more of these may be children of Root, but at least one is required, and all instances must be unique.

Required attributes
url
The canonical path of the licensed work represented by this <content> element; also provides the canonical identifier for the license

Optional attributes
server
The URL of an RSL License Server implementing the Open License Protocol
encrypted
If true, the work's canonical asset is encrypted, and the specified server must support the Encrypted Media Standard
lastmod
A timestamp in RFC 3339 format indicating when the work's canonical asset was last modified

Required content
license
One or more <license> elements that collectively define the rights, costs, and restrictions associated with the work

Optional content
schema
Schema.org metadata associated with the work
alternate
One or more alternative digital formats of the work
copyright
The individual or organization owning or controlling the rights to the work
terms
The URL path to a terms of service document or supplemental legal information which is not encoded in XML

Constructors

Constructor Description

Content(url, license, ?schema, ?alternate, ?copyright, ?terms, ?server, ?encrypted, ?lastmod)

Full Usage: Content(url, license, ?schema, ?alternate, ?copyright, ?terms, ?server, ?encrypted, ?lastmod)

Parameters:
Returns: Content
url : Uri
license : License list
?schema : Schema
?alternate : Alternate list
?copyright : Copyright
?terms : Uri
?server : Uri
?encrypted : bool
?lastmod : DateTime
Returns: Content

Type something to start searching.