Copyright (Fornax.Seo)1.6.0 Fornax.Seo

Copyright Type

The <copyright> element of an RSL document

One of these may be a child of Content

Record fields

Record Field Description

ContactEmail

Full Usage: ContactEmail

Field type: string

Email address for inquiries or licensing negotiations

Field type: string

ContactUrl

Full Usage: ContactUrl

Field type: string

URL to a web-based contact method, such as a contact form or page

Field type: string

Type

Full Usage: Type

Field type: CopyrightHolder option

Specifies whether the copyright holder is a person or an organization

Field type: CopyrightHolder option

Type something to start searching.