License (Fornax.Seo)1.6.0 Fornax.Seo

License Type

The <license> element of an RSL document

One or more of these may be children of the Content element, but at least one is required, and all instances must be unique

Record fields

Record Field Description

Legal

Full Usage: Legal

Field type: Legal list option

Legally binding metadata specifying the authority, guarantees, and disclaimers of the license

Field type: Legal list option

Payment

Full Usage: Payment

Field type: Payment option

Defines how users must compensate the licensor for permitted uses of the licensed work

Field type: Payment option

Permits

Full Usage: Permits

Field type: Permits list option

The activities, users, or jurisdictions that are explicitly allowed under the license

Field type: Permits list option

Prohibits

Full Usage: Prohibits

Field type: Prohibits list option

The activities that are explicitly forbidden, even if they would otherwise be permitted

Field type: Prohibits list option

Static members

Static member Description

License.FreeAndOpenSource(license)

Full Usage: License.FreeAndOpenSource(license)

Parameters:
    license : string - A link to the text of an open source licence, or the identifier of a standard license in the SPDX index

Returns: License A default <license> implying freedom to use without payment in search engines, under the terms of the specified license, and not for any kind of AI content generation
license : string

A link to the text of an open source licence, or the identifier of a standard license in the SPDX index

Returns: License

A default <license> implying freedom to use without payment in search engines, under the terms of the specified license, and not for any kind of AI content generation

License.FreeAndSearchable

Full Usage: License.FreeAndSearchable

Returns: License A default <license> implying freedom to use without payment or attribution in search engines only, and not for any kind of AI content generation
Returns: License

A default <license> implying freedom to use without payment or attribution in search engines only, and not for any kind of AI content generation

Type something to start searching.