Rsl (Fornax.Seo)1.6.0 Fornax.Seo

Rsl Module

Element attribute types and qualifiers

Types and nested modules

Type/Module Description

Scopes

Permitted type attribute values for element children of License

CopyrightHolder

Permitted values of Copyright.Type

CurrencyCode

Permitted values of Amount.Currency

Disposition

Specifies whether an element defines permissions or restrictions regarding usage of a licensed work

Type something to start searching.