Legal (Fornax.Seo)1.6.0 Fornax.Seo

Legal Type

Uniquely identifies an element of type Legal

Union cases

Union case Description

Attestation

Full Usage: Attestation

Qualifies a Legal element by affirming the publisher's authority to assert the rights described in the license

Contact

Full Usage: Contact

Qualifies a Legal element by providing the web address or email of the licensed work's copyright holder

Disclaimer

Full Usage: Disclaimer

Qualifies a Legal element by disclaiming or qualifying any warranties offered on the licensed work

Proof

Full Usage: Proof

Qualifies a Legal element by providing one or more hyperlinks proving the identity of the licensed work's copyright holder

Warranty

Full Usage: Warranty

Qualifies a Legal element by declaring one or more warranties offered on the licensed work

Instance members

Instance member Description

this.IsAttestation

Full Usage: this.IsAttestation

Returns: bool
Returns: bool

this.IsContact

Full Usage: this.IsContact

Returns: bool
Returns: bool

this.IsDisclaimer

Full Usage: this.IsDisclaimer

Returns: bool
Returns: bool

this.IsProof

Full Usage: this.IsProof

Returns: bool
Returns: bool

this.IsWarranty

Full Usage: this.IsWarranty

Returns: bool
Returns: bool

Type something to start searching.