Payment (Fornax.Seo)1.6.0 Fornax.Seo

Payment Type

Uniquely identifies an element of type Payment

Union cases

Union case Description

Attribution

Full Usage: Attribution

Qualifies a Payment element by requiring visible credit and a functional link to the original of the licensed work

Contribution

Full Usage: Contribution

Qualifies a Payment element by requiring a monetary or in-kind contribution to support the development or maintenance of the licensed work

Crawl

Full Usage: Crawl

Qualifies a Payment element by requiring compensation every time the licensed work is crawled

Free

Full Usage: Free

Qualifies a Payment element by waiving any demand for compensation

Purchase

Full Usage: Purchase

Qualifies a Payment element by requiring the purchase of the licensed work

Subscription

Full Usage: Subscription

Qualifies a Payment element by requiring a recurring payment to access the licensed work

Training

Full Usage: Training

Qualifies a Payment element by requiring compensation every time the licensed work is used for AI training

Use

Full Usage: Use

Qualifies a Payment element by requiring compensation every time the licensed work contributes to AI-generated output

Instance members

Instance member Description

this.IsAttribution

Full Usage: this.IsAttribution

Returns: bool
Returns: bool

this.IsContribution

Full Usage: this.IsContribution

Returns: bool
Returns: bool

this.IsCrawl

Full Usage: this.IsCrawl

Returns: bool
Returns: bool

this.IsFree

Full Usage: this.IsFree

Returns: bool
Returns: bool

this.IsPurchase

Full Usage: this.IsPurchase

Returns: bool
Returns: bool

this.IsSubscription

Full Usage: this.IsSubscription

Returns: bool
Returns: bool

this.IsTraining

Full Usage: this.IsTraining

Returns: bool
Returns: bool

this.IsUse

Full Usage: this.IsUse

Returns: bool
Returns: bool

Type something to start searching.