Permission (Fornax.Seo)1.6.0 Fornax.Seo

Permission Type

Uniquely identifies an element of type Permits or Prohibits

Union cases

Union case Description

Geo

Full Usage: Geo

Qualifies an instance of PermittedUsage, or a derived type, by restricting usage to one or more geographic regions

Usage

Full Usage: Usage

Qualifies an instance of PermittedUsage, or a derived type, by specifying allowed forms of usage by an AI system

User

Full Usage: User

Qualifies an instance of PermittedUsage, or a derived type, by restricting a license to certain classes of end users

Instance members

Instance member Description

this.IsGeo

Full Usage: this.IsGeo

Returns: bool
Returns: bool

this.IsUsage

Full Usage: this.IsUsage

Returns: bool
Returns: bool

this.IsUser

Full Usage: this.IsUser

Returns: bool
Returns: bool

Type something to start searching.