Xml (Fornax.Seo)1.6.0 Fornax.Seo

Xml Module

XML generation utilities

Types

Type Description

DocumentBuilder<'TSource>

Transforms (X/HT)ML markup text into XML documents or fragments

Functions and values

Function or value Description

getValidationEventHandler helpLink

Full Usage: getValidationEventHandler helpLink

Parameters:
    helpLink : string - An optional link to additional information about the last exception

Returns: ValidationEventHandler

Creates a default handler for XML schema validation events

Events tagged with a XmlSeverityType of Error will rethrow the last exception. All other events are logged to either the (Windows) user's temp file directory, or the active application's directory

helpLink : string

An optional link to additional information about the last exception

Returns: ValidationEventHandler

Type something to start searching.