Core Module
Extends the Fornax DSL with SEO meta tag generators
Functions and values
| Function or value |
Description
|
||
Full Usage:
rsl page license
Parameters:
ContentObject
-
The web page to which the license will apply
license : License option
-
An optional License; if None, the return value of
License.FreeAndSearchable is used
Returns: HtmlElement
A <script> tag containing an RSL license for the given page
|
Generates an inline RSL license for an individual web page
|
||
Full Usage:
seo page
Parameters:
ContentObject
Returns: HtmlElement list
A list of <meta> tags with OpenGraph data and a <script> tag with JSON-LD
structured data
|
Generates structured data and OpenGraph tags
If page's
|
||
Full Usage:
socialMedia author
Parameters:
ContentCreator
Returns: HtmlElement list
A list of social media links decorated with matching Font Awesome icons
|
Generates links to the social media profiles of the given author
|
Fornax.Seo