Rsl Module
A (partial) implementation of the RSL 1.0 specification
Types and nested modules
| Type/Module | Description |
|
The component elements of an RSL document |
|
|
XML validation utilities for RSL licenses |
|
|
An RSL element attribute |
|
|
Permitted values of an RSL element attribute |
|
|
Provides RSL elements with HTML generation methods |
|
|
A unique RSL element specifying the permitted or prohibited usage of a licensed work |
|
|
An RSL element that should not have the same |
Functions and values
| Function or value |
Description
|
Full Usage:
toHtmlElement elem
Parameters:
'T
-
An RSL element type provided by the DOM module
Returns: HtmlElement
Modifiers: inline Type parameters: 'T |
|
Full Usage:
toHtmlString elem
Parameters:
'T
-
An RSL element type provided by the DOM module
Returns: string
Modifiers: inline Type parameters: 'T |
|
Full Usage:
toXmlDocument elem
Parameters:
'T
-
An RSL element type provided by the DOM module
Returns: DocumentBuilder<'T>
Modifiers: inline Type parameters: 'T |
Transforms an RSL element into an XML document or fragment, without validating the contents
|
Fornax.Seo