Legal Type
The <legal> element of an RSL document
One or more of these may be a child of License, but each must have a unique type attribute.
For the specifics parameter, a non-empty, comma-delimited string of one or more
appropriate terms is required when
scope is Warranty
or Disclaimer.
Example
open Fornax.Seo.Rsl.DOM
open Fornax.Seo.Standards.Rsl
let hasWarranty = Legal (Scopes.Legal.Warranty, "ownership,authority,no-infringement")
let hasDisclaimer = Legal (Scopes.Legal.Disclaimer, "as-is,no-liability")
let hasAttestation = Legal (Scopes.Legal.Attestation, "true")
let hasContact = Legal (Scopes.Legal.Contact, "mailto:info@example.com")
let hasProof = Legal (Scopes.Legal.Proof, "https://blockscan.example/tx/0x9aBcD123")
val hasWarranty: obj
val hasDisclaimer: obj
val hasAttestation: obj
val hasContact: obj
val hasProof: obj
Constructors
| Constructor |
Description
|
|
Fornax.Seo