License Type
The <license> element of an RSL document
One or more of these may be children of the Content element, but at least one is required, and all instances must be unique
Record fields
| Record Field |
Description
|
Legally binding metadata specifying the authority, guarantees, and disclaimers of the license
|
|
Defines how users must compensate the licensor for permitted uses of the licensed work
|
|
The activities, users, or jurisdictions that are explicitly allowed under the license
|
|
The activities that are explicitly forbidden, even if they would otherwise be permitted
|
Static members
| Static member |
Description
|
Full Usage:
License.FreeAndOpenSource(license)
Parameters:
string
-
A link to the text of an open source licence, or the identifier of a standard license in the
SPDX index
Returns: License
A default <license> implying freedom to use without payment in search engines, under
the terms of the specified license, and not for any kind of AI content generation
|
|
Full Usage:
License.FreeAndSearchable
Returns: License
A default <license> implying freedom to use without payment or attribution in search
engines only, and not for any kind of AI content generation
|
|
Fornax.Seo