Payment Type
The <payment> element of an RSL document
One of these may be a child of License, but each must have a unique type attribute.
The default is Free if no scope is provided.
- Optional content
-
amount - Explicit cost and currency
-
accepts - Details regarding supported payment methods
-
standard - The URL path to a public or collective license (e.g., Creative Commons).
-
custom - The URL path to a publisher-specific licensing page (e.g., contact form)
Constructors
| Constructor |
Description
|
|
Fornax.Seo