Permits Type
The <permits> element of an RSL document
One or more of these may be a child of License, but each must have a unique type attribute.
For the specifics parameter, a non-empty, comma-delimited string of one or more
appropriate terms is required.
Example
open Fornax.Seo.Rsl.DOM
open Fornax.Seo.Standards.Rsl
let allowedUsage = Permits (Scopes.Permission.Usage, "ai-input")
let allowedUsers = Permits (Scopes.Permission.User, "non-commercial,education")
let allowedRegions = Permits (Scopes.Permission.Geo, "CA,GB,AU,NZ")
val allowedUsage: obj
val allowedUsers: obj
val allowedRegions: obj
Constructors
| Constructor |
Description
|
Full Usage:
Permits(scope, specifics)
Parameters:
Permission
specifics : string
Returns: Permits
|
|
Static members
| Static member |
Description
|
Full Usage:
Permits.WebSearchOnly
Returns: Permits
A default <permits> element allowing usage for search engine indexing, excluding AI-assisted
search summaries or other kinds of AI content generation
|
|
Fornax.Seo