Prohibits Type
The <prohibits> element of an RSL document
One or more of these may be a child of License, but each must have a unique type attribute.
For the specifics parameter, a non-empty, comma-delimited string of one or more
appropriate terms is required.
Example
open Fornax.Seo.Rsl.DOM
open Fornax.Seo.Standards.Rsl
let deniedUsage = Prohibits (Scopes.Permission.Usage, "ai-train,ai-input")
let deniedUsers = Prohibits (Scopes.Permission.User, "commercial")
let deniedRegions = Prohibits (Scopes.Permission.Geo, "US")
val deniedUsage: obj
val deniedUsers: obj
val deniedRegions: obj
Constructors
| Constructor |
Description
|
Full Usage:
Prohibits(scope, specifics)
Parameters:
Permission
specifics : string
Returns: Prohibits
|
|
Fornax.Seo