Legal Type
Uniquely identifies an element of type Legal
Union cases
| Union case |
Description
|
Full Usage:
Attestation
|
Qualifies a Legal element by affirming the publisher's authority to assert the rights described in the license |
Full Usage:
Contact
|
Qualifies a Legal element by providing the web address or email of the licensed work's copyright holder |
Full Usage:
Disclaimer
|
Qualifies a Legal element by disclaiming or qualifying any warranties offered on the licensed work |
Full Usage:
Proof
|
Qualifies a Legal element by providing one or more hyperlinks proving the identity of the licensed work's copyright holder |
Full Usage:
Warranty
|
Qualifies a Legal element by declaring one or more warranties offered on the licensed work |
Instance members
| Instance member |
Description
|
Full Usage:
this.IsAttestation
Returns: bool
|
|
Full Usage:
this.IsContact
Returns: bool
|
|
Full Usage:
this.IsDisclaimer
Returns: bool
|
|
Full Usage:
this.IsProof
Returns: bool
|
|
Full Usage:
this.IsWarranty
Returns: bool
|
|
Fornax.Seo