Payment Type
Uniquely identifies an element of type Payment
Union cases
| Union case |
Description
|
Full Usage:
Attribution
|
Qualifies a Payment element by requiring visible credit and a functional link to the original of the licensed work |
Full Usage:
Contribution
|
Qualifies a Payment element by requiring a monetary or in-kind contribution to support the development or maintenance of the licensed work |
Full Usage:
Crawl
|
Qualifies a Payment element by requiring compensation every time the licensed work is crawled |
Full Usage:
Free
|
Qualifies a Payment element by waiving any demand for compensation |
Full Usage:
Purchase
|
Qualifies a Payment element by requiring the purchase of the licensed work |
Full Usage:
Subscription
|
Qualifies a Payment element by requiring a recurring payment to access the licensed work |
Full Usage:
Training
|
Qualifies a Payment element by requiring compensation every time the licensed work is used for AI training |
Full Usage:
Use
|
Qualifies a Payment element by requiring compensation every time the licensed work contributes to AI-generated output |
Instance members
| Instance member |
Description
|
Full Usage:
this.IsAttribution
Returns: bool
|
|
Full Usage:
this.IsContribution
Returns: bool
|
|
Full Usage:
this.IsCrawl
Returns: bool
|
|
Full Usage:
this.IsFree
Returns: bool
|
|
Full Usage:
this.IsPurchase
Returns: bool
|
|
Full Usage:
this.IsSubscription
Returns: bool
|
|
Full Usage:
this.IsTraining
Returns: bool
|
|
Full Usage:
this.IsUse
Returns: bool
|
|
Fornax.Seo