Permission Type
Union cases
| Union case |
Description
|
Full Usage:
Geo
|
Qualifies an instance of PermittedUsage, or a derived type, by restricting usage to one or more geographic regions |
Full Usage:
Usage
|
Qualifies an instance of PermittedUsage, or a derived type, by specifying allowed forms of usage by an AI system |
Full Usage:
User
|
Qualifies an instance of PermittedUsage, or a derived type, by restricting a license to certain classes of end users |
Instance members
| Instance member |
Description
|
Full Usage:
this.IsGeo
Returns: bool
|
|
Full Usage:
this.IsUsage
Returns: bool
|
|
Full Usage:
this.IsUser
Returns: bool
|
|
Fornax.Seo