DocumentBuilder<'TSource> Type
Transforms (X/HT)ML markup text into XML documents or fragments
Record fields
| Record Field |
Description
|
|
The settings used to parse incoming markup text
|
|
The underlying XML document object of this DocumentBuilder
|
|
The settings used by the underlying document object to create XML
|
Constructors
| Constructor |
Description
|
Full Usage:
DocumentBuilder(schema, ?eventHandler, ?writeXmlDecl, ?writeBom, ?minify)
Parameters:
XmlSchema
-
The XML schema used to validate source markup text. No validation is performed if this argument is null
?eventHandler : ValidationEventHandler
-
An optional handler for schema validation errors
?writeXmlDecl : bool
-
true to include the <?xml ...?> declaration in generated documents (omitted if the source markup
is a document fragment). The default is true
?writeBom : bool
-
true to include a Unicode byte order mark in generated document text. The default is false
?minify : bool
-
true to remove indentation and whitespace from the generated document or fragment, not including text in the scope
of the
xml:space="preserve" attribute.
The default is false
Returns: DocumentBuilder<'TSource>
|
Creates a new DocumentBuilder with the given XML schema, optional validation event handler, and output format options
|
|
Creates a new DocumentBuilder
|
Instance members
| Instance member |
Description
|
||
Full Usage:
this.AsMarkup
Parameters:
'TSource
Returns: string
Modifiers: abstract |
When overridden by a derived class, returns a string of (X/HT)ML markup representing the given instance
Example
Multiple items
type MarkupSource = new: unit -> MarkupSource -------------------- new: unit -> MarkupSource val builder: obj
val doclet: MarkupSource
|
||
Full Usage:
this.Create
Parameters:
'TSource
-
Any type that can be represented as an (X/HT)ML string
|
Parses the markup provided by source and loads it into the underlying document object
|
||
Full Usage:
this.TryCreate
Parameters:
'TSource
-
Any type that can be represented as an (X/HT)ML string
Returns: bool
true if source was parsed and loaded successfully; otherwise false
|
Non-throwing alternative to DocumentBuilder.Create
|
Fornax.Seo